<?php

/*********************************************************************

 スケジュールレスポンスプラグイン (2014/08/22)

 freo.jp
 customize by 32877(http://32877.xii.jp)

*********************************************************************/

//外部ファイル読み込み
require_once FREO_MAIN_DIR . 'freo/plugins/security_plugin_scheduleres.php';

/* メイン処理 */
function freo_page_scheduleres()
{
	global $freo;

	switch ($_REQUEST['freo']['work']) {
		case 'setup':
			freo_page_scheduleres_setup();
			break;
		case 'setup_execute':
			freo_page_scheduleres_setup_execute();
			break;
		case 'admin':
			freo_page_scheduleres_admin();
			break;
		case 'admin_form':
			freo_page_scheduleres_admin_form();
			break;
		case 'admin_post':
			freo_page_scheduleres_admin_post();
			break;
		case 'form':
			freo_page_scheduleres_form();
			break;
		case 'post':
			freo_page_scheduleres_post();
			break;
		case 'admin_delete':
			freo_page_scheduleres_admin_delete();
			break;
		default:
			freo_page_scheduleres_default();
	}

	return;
}

/* セットアップ */
function freo_page_scheduleres_setup()
{
	global $freo;

	//ログイン状態確認
	if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
		freo_redirect('login', true);
	}

	//リクエストメソッドに応じた処理を実行
	if ($_SERVER['REQUEST_METHOD'] == 'POST') {
		//ワンタイムトークン確認
		if (!freo_token('check')) {
			$freo->smarty->append('errors', '不正なアクセスです。');
		}

		//エラー確認
		if (!$freo->smarty->get_template_vars('errors')) {
			freo_redirect('scheduleres/setup_execute?freo%5Btoken%5D=' . freo_token('create'), true);
		}
	}

	//データ割当
	$freo->smarty->assign(array(
		'token'       => freo_token('create'),
		'plugin_id'   => 'scheduleres',
		'plugin_name' => FREO_PLUGIN_SCHEDULERES_NAME
	));

	//データ出力
	freo_output('plugins/setup.html');

	return;
}

/* セットアップ | セットアップ実行 */
function freo_page_scheduleres_setup_execute()
{
	global $freo;

	//ログイン状態確認
	if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
		freo_redirect('login', true);
	}

	//ワンタイムトークン確認
	if (!freo_token('check')) {
		freo_redirect('setup?error=1', true);
	}

	//データベーステーブル存在検証
	if (FREO_DATABASE_TYPE == 'mysql') {
		$query = 'SHOW TABLES';
	} else {
		$query = 'SELECT name FROM sqlite_master WHERE type = \'table\'';
	}
	$stmt = $freo->pdo->query($query);
	if (!$stmt) {
		freo_error($freo->pdo->errorInfo());
	}

	$table = array();
	while ($data = $stmt->fetch(PDO::FETCH_NUM)) {
		$table[$data[0]] = true;
	}

	//データベーステーブル定義
	if (FREO_DATABASE_TYPE == 'mysql') {
		$queries = array(
			'plugin_schedulereses' => '(
				id INT UNSIGNED NOT NULL AUTO_INCREMENT,
				created DATETIME NOT NULL,
				modified DATETIME NOT NULL,
				name VARCHAR(255),
				url TEXT,
				mail TEXT,
				text TEXT NOT NULL,
				schedule_id INT UNSIGNED,
				option01    TEXT,
				option02    TEXT,
				option03    TEXT,
				option04    TEXT,
				option05    TEXT,
				option06    TEXT,
				option07    TEXT,
				option08    TEXT,
				option09    TEXT,
				option10    TEXT,
				ip VARCHAR(80) NOT NULL,
				user_id VARCHAR(255),
				restriction VARCHAR(20),
				PRIMARY KEY(id)
			)'
		);
	} else {
		$queries = array(
			'plugin_schedulereses' => '(
				id INTEGER,
				created DATETIME NOT NULL,
				modified DATETIME NOT NULL,
				name VARCHAR,
				url TEXT,
				mail TEXT,
				text TEXT NOT NULL,
				schedule_id INTEGER,
				option01    TEXT,
				option02    TEXT,
				option03    TEXT,
				option04    TEXT,
				option05    TEXT,
				option06    TEXT,
				option07    TEXT,
				option08    TEXT,
				option09    TEXT,
				option10    TEXT,
				ip VARCHAR NOT NULL, 
				user_id VARCHAR,
				restriction VARCHAR,
				PRIMARY KEY(id)
			)'
		);
	}

	//データベーステーブル作成
	foreach ($queries as $name => $query) {
		if (empty($table[FREO_DATABASE_PREFIX . $name])) {
			$stmt = $freo->pdo->query('CREATE TABLE ' . FREO_DATABASE_PREFIX . $name . $query);
			if (!$stmt) {
				freo_error($freo->pdo->errorInfo());
			}
		}
	}

	//ログ記録
	freo_log(FREO_PLUGIN_RESPONSE_NAME . 'のセットアップを実行しました。');

	//完了画面へ移動
	freo_redirect('scheduleres/setup?exec=setup', true);

	return;
}

/* 管理画面 | スケジュールレスポンス管理 */
function freo_page_scheduleres_admin()
{
	global $freo;

	//ログイン状態確認
	if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
		freo_redirect('login', true);
	}

	//パラメータ検証
	if (!isset($_GET['page']) or !preg_match('/^\d+$/', $_GET['page']) or $_GET['page'] < 1) {
		$_GET['page'] = 1;
	}

	//検索条件設定
	$condition = null;
	if (isset($_GET['word'])) {
		$condition .= ' AND text LIKE ' . $freo->pdo->quote('%' . $_GET['word'] . '%') . ' OR name LIKE ' . $freo->pdo->quote('%' . $_GET['word'] . '%');
	}
	if (isset($_GET['date'])) {
		if (preg_match('/^\d\d\d\d$/', $_GET['date'])) {
			if (FREO_DATABASE_TYPE == 'mysql') {
				$condition .= ' AND DATE_FORMAT(created, \'%Y\') = ' . $freo->pdo->quote($_GET['date']);
			} else {
				$condition .= ' AND STRFTIME(\'%Y\', created) = ' . $freo->pdo->quote($_GET['date']);
			}
		} elseif (preg_match('/^\d\d\d\d\d\d$/', $_GET['date'])) {
			if (FREO_DATABASE_TYPE == 'mysql') {
				$condition .= ' AND DATE_FORMAT(created, \'%Y%m\') = ' . $freo->pdo->quote($_GET['date']);
			} else {
				$condition .= ' AND STRFTIME(\'%Y%m\', created) = ' . $freo->pdo->quote($_GET['date']);
			}
		} elseif (preg_match('/^\d\d\d\d\d\d\d\d$/', $_GET['date'])) {
			if (FREO_DATABASE_TYPE == 'mysql') {
				$condition .= ' AND DATE_FORMAT(created, \'%Y%m%d\') = ' . $freo->pdo->quote($_GET['date']);
			} else {
				$condition .= ' AND STRFTIME(\'%Y%m%d\', created) = ' . $freo->pdo->quote($_GET['date']);
			}
		}
	}
	if ($condition) {
		$condition = ' WHERE id IS NOT NULL ' . $condition;
	}

	//スケジュールレスポンス取得
	$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'plugin_schedulereses ' . $condition . ' ORDER BY id DESC LIMIT :start, :limit');
	$stmt->bindValue(':start', intval($freo->config['plugin']['scheduleres']['admin_limit']) * ($_GET['page'] - 1), PDO::PARAM_INT);
	$stmt->bindValue(':limit', intval($freo->config['plugin']['scheduleres']['admin_limit']), PDO::PARAM_INT);
	$flag = $stmt->execute();
	if (!$flag) {
		freo_error($stmt->errorInfo());
	}

	$plugin_schedulereses = array();
	while ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$plugin_schedulereses[$data['id']] = $data;
	}

	//スケジュールレスポンスID取得
	$plugin_scheduleres_keys = array_keys($plugin_schedulereses);

	//スケジュールレスポンス数・ページ数取得
	$stmt = $freo->pdo->query('SELECT COUNT(*) FROM ' . FREO_DATABASE_PREFIX . 'plugin_schedulereses ' . $condition);
	if (!$stmt) {
		freo_error($freo->pdo->errorInfo());
	}

	$data                  = $stmt->fetch(PDO::FETCH_NUM);
	$plugin_scheduleres_count = $data[0];
	$plugin_scheduleres_page  = ceil($plugin_scheduleres_count / $freo->config['plugin']['scheduleres']['admin_limit']);


	//データ割当
	$freo->smarty->assign(array(
		'token'                 => freo_token('create'),
		'plugin_schedulereses'      => $plugin_schedulereses,
		'plugin_scheduleres_count' => $plugin_scheduleres_count,
		'plugin_scheduleres_page'  => $plugin_scheduleres_page,
	));

	return;
}

/* 管理画面 | スケジュールレスポンス入力 */
function freo_page_scheduleres_admin_form()
{
	global $freo;

	//ログイン状態確認
	if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
		freo_redirect('login', true);
	}

	//パラメータ検証
	if (!isset($_GET['id']) or !preg_match('/^\d+$/', $_GET['id']) or $_GET['id'] < 1) {
		$_GET['id'] = 0;
	}

	//リクエストメソッドに応じた処理を実行
	if ($_SERVER['REQUEST_METHOD'] == 'POST') {
		//ワンタイムトークン確認
		if (!freo_token('check')) {
			$freo->smarty->append('errors', '不正なアクセスです。');
		}

		//入力データ検証
		if (!$freo->smarty->get_template_vars('errors')) {

			//名前
			if ($_POST['plugin_scheduleres']['name'] != '' and mb_strlen($_POST['plugin_scheduleres']['name'], 'UTF-8') > 200) {
				$freo->smarty->append('errors', '名前は200文字以内で入力してください。');
			}

			//本文
			if ($_POST['plugin_scheduleres']['text'] == '') {
				$freo->smarty->append('errors', '本文を入力してください。');
			} elseif (mb_strlen($_POST['plugin_scheduleres']['text'], 'UTF-8') > 5000) {
				$freo->smarty->append('errors', '本文は5000文字以内で入力してください。');
			}
		}

		//エラー確認
		if ($freo->smarty->get_template_vars('errors')) {
			//エラー表示
			$plugin_scheduleres = $_POST['plugin_scheduleres'];
		} else {
			$_SESSION['input'] = $_POST;

			//登録処理へ移動
			freo_redirect('scheduleres/admin_post?freo%5Btoken%5D=' . freo_token('create') . ($_GET['id'] ? '&id=' . $_GET['id'] : ''));
		}
	} else {
		if ($_GET['id']) {
			//編集データ取得
			$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'plugin_schedulereses WHERE id = :id');
			$stmt->bindValue(':id', $_GET['id']);
			$flag = $stmt->execute();
			if (!$flag) {
				freo_error($stmt->errorInfo());
			}

			if ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
				$plugin_scheduleres = $data;
			} else {
				freo_error('指定されたスケジュールレスポンスが見つかりません。', '404 Not Found');
			}
		} else {
			//ユーザー取得
			$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'users WHERE id = :id');
			$stmt->bindValue(':id', $freo->user['id']);
			$flag = $stmt->execute();
			if (!$flag) {
				freo_error($stmt->errorInfo());
			}

			if ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
				$user = $data;
			} else {
				freo_error('指定されたユーザーが見つかりません。', '404 Not Found');
			}

			//新規データ設定
			$plugin_scheduleres = array(
				'name' => $user['name'],
				'mail' => $user['mail'],
				'url'  => $user['url'],
			);
		}
	}

	//データ割当
	$freo->smarty->assign(array(
		'token' => freo_token('create'),
		'input' => array(
			'plugin_scheduleres' => $plugin_scheduleres
		)
	));

	return;
}

/* 管理画面 | スケジュールレスポンス登録 */
function freo_page_scheduleres_admin_post()
{
	global $freo;

	//ログイン状態確認
	if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
		freo_redirect('login', true);
	}

	//入力データ確認
	if (empty($_SESSION['input'])) {
		freo_redirect('scheduleres/admin?error=1');
	}

	//ワンタイムトークン確認
	if (!freo_token('check')) {
		freo_redirect('scheduleres/admin?error=1');
	}

	//入力データ取得
	$scheduleres = $_SESSION['input']['plugin_scheduleres'];

	if ($scheduleres['name'] == '') {
		$scheduleres['name'] = $freo->config['plugin']['scheduleres']['noname'];
	}
	if ($scheduleres['mail'] == '') {
		$scheduleres['mail'] = null;
	}
	if ($scheduleres['url'] == '') {
		$scheduleres['url'] = null;
	}
	if ($scheduleres['schedule_id'] == '') {
		$scheduleres['schedule_id'] = null;
	}
	if ($scheduleres['option01'] == '') {
		$scheduleres['option01'] = null;
	}
	if ($scheduleres['option02'] == '') {
		$scheduleres['option02'] = null;
	}
	if ($scheduleres['option03'] == '') {
		$scheduleres['option03'] = null;
	}
	if ($scheduleres['option04'] == '') {
		$scheduleres['option04'] = null;
	}
	if ($scheduleres['option05'] == '') {
		$scheduleres['option05'] = null;
	}
	if ($scheduleres['option06'] == '') {
		$scheduleres['option06'] = null;
	}
	if ($scheduleres['option07'] == '') {
		$scheduleres['option07'] = null;
	}
	if ($scheduleres['option08'] == '') {
		$scheduleres['option08'] = null;
	}
	if ($scheduleres['option09'] == '') {
		$scheduleres['option09'] = null;
	}
	if ($scheduleres['option10'] == '') {
		$scheduleres['option10'] = null;
	}
	if ($scheduleres['user_id'] == '') {
		$scheduleres['user_id'] = null;
	}
	if ($scheduleres['restriction'] == '') {
		$scheduleres['restriction'] = null;
	}

	//データ登録
	if (isset($_GET['id'])) {
		$stmt = $freo->pdo->prepare('UPDATE ' . FREO_DATABASE_PREFIX . 'plugin_schedulereses SET modified = :now, name = :name, url = :url, mail = :mail, text = :text, schedule_id = :schedule_id, option01 = :option01, option02 = :option02, option03 = :option03, option04 = :option04, option05 = :option05, option06 = :option06, option07 = :option07, option08 = :option08, option09 = :option09, option10 = :option10, ip = :ip, user_id = :user_id, restriction = :restriction WHERE id = :id');
		$stmt->bindValue(':now',             date('Y-m-d H:i:s'));
		$stmt->bindValue(':name',            $scheduleres['name']);
		$stmt->bindValue(':url',             $scheduleres['url']);
		$stmt->bindValue(':mail',            $scheduleres['mail']);
		$stmt->bindValue(':text',            $scheduleres['text']);
		$stmt->bindValue(':schedule_id',         $scheduleres['schedule_id']);
		$stmt->bindValue(':option01',        $scheduleres['option01']);
		$stmt->bindValue(':option02',        $scheduleres['option02']);
		$stmt->bindValue(':option03',        $scheduleres['option03']);
		$stmt->bindValue(':option04',        $scheduleres['option04']);
		$stmt->bindValue(':option05',        $scheduleres['option05']);
		$stmt->bindValue(':option06',        $scheduleres['option06']);
		$stmt->bindValue(':option07',        $scheduleres['option07']);
		$stmt->bindValue(':option08',        $scheduleres['option08']);
		$stmt->bindValue(':option09',        $scheduleres['option09']);
		$stmt->bindValue(':option10',        $scheduleres['option10']);
		$stmt->bindValue(':ip',              $_SERVER['REMOTE_ADDR']);
		$stmt->bindValue(':user_id',         $scheduleres['user_id']);
		$stmt->bindValue(':restriction',     $scheduleres['restriction']);
		$stmt->bindValue(':id',              $scheduleres['id'], PDO::PARAM_INT);
		$flag = $stmt->execute();
		if (!$flag) {
			freo_error($stmt->errorInfo());
		}
	} else {
		$stmt = $freo->pdo->prepare('INSERT INTO ' . FREO_DATABASE_PREFIX . 'plugin_schedulereses VALUES(NULL, :now1, :now2, :name, :url, :mail, :text, :schedule_id, :option01, :option02, :option03, :option04, :option05, :option06, :option07, :option08, :option09, :option10, :ip, :user_id, :restriction)');
		$stmt->bindValue(':now1',        date('Y-m-d H:i:s'));
		$stmt->bindValue(':now2',        date('Y-m-d H:i:s'));
		$stmt->bindValue(':name',        $scheduleres['name']);
		$stmt->bindValue(':url',         $scheduleres['url']);
		$stmt->bindValue(':text',        $scheduleres['text']);
		$stmt->bindValue(':schedule_id',    $scheduleres['schedule_id']);
		$stmt->bindValue(':option01',    $scheduleres['option01']);
		$stmt->bindValue(':option02',    $scheduleres['option02']);
		$stmt->bindValue(':option03',    $scheduleres['option03']);
		$stmt->bindValue(':option04',    $scheduleres['option04']);
		$stmt->bindValue(':option05',    $scheduleres['option05']);
		$stmt->bindValue(':option06',    $scheduleres['option06']);
		$stmt->bindValue(':option07',    $scheduleres['option07']);
		$stmt->bindValue(':option08',    $scheduleres['option08']);
		$stmt->bindValue(':option09',    $scheduleres['option09']);
		$stmt->bindValue(':option10',    $scheduleres['option10']);
		$stmt->bindValue(':ip',          $_SERVER['REMOTE_ADDR']);
		$stmt->bindValue(':user_id',     $scheduleres['user_id']);
		$stmt->bindValue(':restriction', $scheduleres['restriction']);
		$flag = $stmt->execute();
		if (!$flag) {
			freo_error($stmt->errorInfo());
		}
		$scheduleres['id']           = $freo->pdo->lastInsertId();
	}

	//入力データ破棄
	$_SESSION['input'] = array();

	//ログ記録
	if (isset($_GET['id'])) {
		freo_log('スケジュールレスポンスを編集しました。');
	} else {
		freo_log('スケジュールレスポンスを新規に登録しました。');
	}

	//スケジュールレスポンス管理へ移動
	if (isset($_GET['id'])) {
		freo_redirect('scheduleres/admin?exec=update&id=' . $scheduleres['id']);
	} else {
		freo_redirect('scheduleres/admin?exec=insert');
	}

	return;
}

/* 管理画面 | スケジュールレスポンス入力 */
function freo_page_scheduleres_form()
{
	global $freo;

	//ログイン状態確認
	if ($freo->config['plugin']['scheduleres']['authority'] == 'user') {
		if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
			freo_redirect('login', true);
		}
	}

	//パラメータ検証
	if (!isset($_GET['id']) or !preg_match('/^\d+$/', $_GET['id']) or $_GET['id'] < 1) {
		$_GET['id'] = 0;
	}

	//リクエストメソッドに応じた処理を実行
	if ($_SERVER['REQUEST_METHOD'] == 'POST') {
		//ワンタイムトークン確認
		if (!freo_token('check')) {
			$freo->smarty->append('errors', '不正なアクセスです。');
		}

		//入力データ検証
		if (!$freo->smarty->get_template_vars('errors')) {
			//名前
			if ($_POST['plugin_scheduleres']['name'] != '' and mb_strlen($_POST['plugin_scheduleres']['name'], 'UTF-8') > 200) {
				$freo->smarty->append('errors', '名前は200文字以内で入力してください。');
			}
			//本文
			if ($_POST['plugin_scheduleres']['text'] == '') {
				$freo->smarty->append('errors', '本文を入力してください。');
			} elseif (mb_strlen($_POST['plugin_scheduleres']['text'], 'UTF-8') > 5000) {
				$freo->smarty->append('errors', '本文は5000文字以内で入力してください。');
			}
		}

		//エラー確認
		if ($freo->smarty->get_template_vars('errors')) {
			//エラー表示
			$plugin_scheduleres = $_POST['plugin_scheduleres'];
		} else {
			$_SESSION['input'] = $_POST;

			//登録処理へ移動
			freo_redirect('scheduleres/post?freo%5Btoken%5D=' . freo_token('create') . ($_GET['id'] ? '&id=' . $_GET['id'] : ''));
		}
	} else {

		if ($_GET['id']) {
			//ログイン状態確認
			if (!$freo->user['id']) {
				freo_redirect('login', true);
			}

			//権限確認
			if ($freo->user['authority'] != 'root') {
				$stmt = $freo->pdo->prepare('SELECT user_id FROM ' . FREO_DATABASE_PREFIX . 'plugin_schedulereses WHERE id = :id');
				$stmt->bindValue(':id', $_GET['id'], PDO::PARAM_INT);
				$flag = $stmt->execute();
				if (!$flag) {
					freo_error($stmt->errorInfo());
				}

				if ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
					if ($freo->user['id'] != $data['user_id']) {
						freo_error('この記事を編集する権限がありません。');
					}
				}
			}

			//編集データ取得
			$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'plugin_schedulereses WHERE id = :id');
			$stmt->bindValue(':id', $_GET['id'], PDO::PARAM_INT);
			$flag = $stmt->execute();
			if (!$flag) {
				freo_error($stmt->errorInfo());
			}

			if ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
				$plugin_scheduleres = $data;
			} else {
				freo_error('指定されたスケジュールレスポンスが見つかりません。');
			}
		} else {
			//ユーザー取得
			$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'users WHERE id = :id');
			$stmt->bindValue(':id', $freo->user['id']);
			$flag = $stmt->execute();
			if (!$flag) {
				freo_error($stmt->errorInfo());
			}

			if ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
				$user = $data;
			}

			//新規データ設定
			if ($freo->user['id']) {
				$plugin_scheduleres = array(
					'name' => $user['name'],
					'mail' => $user['mail'],
					'url'  => $user['url'],
				);
			} else {
				$plugin_scheduleres = array();
			}
		}
	}

	//スケジュールID取得
	$target_id = $_GET['schedule_id'];

	//スケジュール取得
	$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'plugin_schedules WHERE id = :id');
	$stmt->bindValue(':id', $target_id);
	$flag = $stmt->execute();
	if (!$flag) {
		freo_error($stmt->errorInfo());
	}

	if ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$plugin_schedule = $data;
	} else {
		freo_error('指定されたスケジュールが見つかりません。');
	}

	//スケジュールタグ取得
	if ($plugin_schedule['tag']) {
		$plugin_schedule_tags = explode(',', $plugin_schedule['tag']);
	} else {
		$plugin_schedule_tags = array();
	}

	//スケジュール取得
	$plugin_schedule_files = array();

	$file_dir = FREO_FILE_DIR . 'plugins/schedule_files/' . $target_id . '/';
	$thumbnail_dir = FREO_FILE_DIR . 'plugins/schedule_thumbnails/' . $target_id . '/';

	if (file_exists($file_dir)) {
		if ($dir = scandir($file_dir)) {
			foreach ($dir as $data) {
				if (is_file($file_dir . $data) and preg_match("/(\w+)\.\w+$/", $data, $matches)) {
					list($width, $height, $size) = freo_file($file_dir . $data);
					if (is_file($thumbnail_dir . $data) and preg_match("/(\w+)\.\w+$/", $data, $matches)) {
						list($thumbnailwidth, $thumbnailheight, $thumbnailsize) = freo_file($thumbnail_dir . $data);
						$thumbnail = array(
							'name'    => $data,
							'width'   => $thumbnailwidth,
							'height'  => $thumbnailheight,
							'size'    => $thumbnailsize
						);
					} else {
						$thumbnail = array();
					}
					$plugin_schedule_files[$matches[1]] = array(
						'name'      => $data,
						'width'     => $width,
						'height'    => $height,
						'size'      => $size,
						'thumbnail' => $thumbnail
					);
				}
			}
		} else {
			freo_error('ファイル保存ディレクトリを開けません。');
		}
	}

	//カテゴリー取得
	$stmt = $freo->pdo->query('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'plugin_schedule_categories ORDER BY sort, id');
	if (!$stmt) {
		freo_error($freo->pdo->errorInfo());
	}
	$plugin_schedule_categories = array();
	while ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$plugin_schedule_categories[$data['id']] = $data;
	}





	//データ割当
	$freo->smarty->assign(array(
		'token' => freo_token('create'),
		'plugin_schedule'             => $plugin_schedule,
		'plugin_schedule_tags'        => $plugin_schedule_tags,
		'plugin_schedule_files'       => $plugin_schedule_files,
		'plugin_schedule_categories'  => $plugin_schedule_categories,
		'input' => array(
			'plugin_scheduleres' => $plugin_scheduleres,
		)
	));

	return;
}

/* 管理画面 | スケジュールレスポンス登録 */
function freo_page_scheduleres_post()
{
	global $freo;

	//入力データ確認
	if (empty($_SESSION['input'])) {
		freo_redirect('scheduleres?error=1');
	}

	//ワンタイムトークン確認
	if (!freo_token('check')) {
		freo_redirect('scheduleres?error=1');
	}

	//入力データ取得
	$scheduleres = $_SESSION['input']['plugin_scheduleres'];

	if ($scheduleres['name'] == '') {
		$scheduleres['name'] = $freo->config['plugin']['scheduleres']['noname'];
	}
	if ($scheduleres['mail'] == '') {
		$scheduleres['mail'] = null;
	}
	if ($scheduleres['url'] == '') {
		$scheduleres['url'] = null;
	}
	if ($scheduleres['schedule_id'] == '') {
		$scheduleres['schedule_id'] = null;
	}
	if ($scheduleres['user_id'] == '') {
		$scheduleres['user_id'] = null;
	}
	if ($scheduleres['option01'] == '') {
		$scheduleres['option01'] = null;
	}
	if ($scheduleres['option02'] == '') {
		$scheduleres['option02'] = null;
	}
	if ($scheduleres['option03'] == '') {
		$scheduleres['option03'] = null;
	}
	if ($scheduleres['option04'] == '') {
		$scheduleres['option04'] = null;
	}
	if ($scheduleres['option05'] == '') {
		$scheduleres['option05'] = null;
	}
	if ($scheduleres['option06'] == '') {
		$scheduleres['option06'] = null;
	}
	if ($scheduleres['option07'] == '') {
		$scheduleres['option07'] = null;
	}
	if ($scheduleres['option08'] == '') {
		$scheduleres['option08'] = null;
	}
	if ($scheduleres['option09'] == '') {
		$scheduleres['option09'] = null;
	}
	if ($scheduleres['option10'] == '') {
		$scheduleres['option10'] = null;
	}
	if ($scheduleres['restriction'] == '') {
		$scheduleres['restriction'] = null;
	}

	//データ登録
	if (isset($_GET['id'])) {
		$stmt = $freo->pdo->prepare('UPDATE ' . FREO_DATABASE_PREFIX . 'plugin_schedulereses SET modified = :now, name = :name, url = :url, mail = :mail, text = :text, schedule_id = :schedule_id, option01 = :option01, option02 = :option02, option03 = :option03, option04 = :option04, option05 = :option05, option06 = :option06, option07 = :option07, option08 = :option08, option09 = :option09, option10 = :option10, ip = :ip, user_id = :user_id, restriction = :restriction WHERE id = :id');
		$stmt->bindValue(':now',             date('Y-m-d H:i:s'));
		$stmt->bindValue(':name',            $scheduleres['name']);
		$stmt->bindValue(':url',             $scheduleres['url']);
		$stmt->bindValue(':mail',            $scheduleres['mail']);
		$stmt->bindValue(':text',            $scheduleres['text']);
		$stmt->bindValue(':schedule_id',        $scheduleres['schedule_id']);
		$stmt->bindValue(':option01',        $scheduleres['option01']);
		$stmt->bindValue(':option02',        $scheduleres['option02']);
		$stmt->bindValue(':option03',        $scheduleres['option03']);
		$stmt->bindValue(':option04',        $scheduleres['option04']);
		$stmt->bindValue(':option05',        $scheduleres['option05']);
		$stmt->bindValue(':option06',        $scheduleres['option06']);
		$stmt->bindValue(':option07',        $scheduleres['option07']);
		$stmt->bindValue(':option08',        $scheduleres['option08']);
		$stmt->bindValue(':option09',        $scheduleres['option09']);
		$stmt->bindValue(':option10',        $scheduleres['option10']);
		$stmt->bindValue(':ip',              $_SERVER['REMOTE_ADDR']);
		$stmt->bindValue(':user_id',         $scheduleres['user_id']);
		$stmt->bindValue(':restriction',     $scheduleres['restriction']);
		$stmt->bindValue(':id',              $scheduleres['id'], PDO::PARAM_INT);
		$flag = $stmt->execute();
		if (!$flag) {
			freo_error($stmt->errorInfo());
		}
	} else {
		$stmt = $freo->pdo->prepare('INSERT INTO ' . FREO_DATABASE_PREFIX . 'plugin_schedulereses VALUES(NULL, :now1, :now2, :name, :url, :mail, :text, :schedule_id, :option01, :option02, :option03, :option04, :option05, :option06, :option07, :option08, :option09, :option10, :ip, :user_id, :restriction)');
		$stmt->bindValue(':now1',        date('Y-m-d H:i:s'));
		$stmt->bindValue(':now2',        date('Y-m-d H:i:s'));
		$stmt->bindValue(':name',        $scheduleres['name']);
		$stmt->bindValue(':url',         $scheduleres['url']);
		$stmt->bindValue(':mail',        $scheduleres['mail']);
		$stmt->bindValue(':text',        $scheduleres['text']);
		$stmt->bindValue(':schedule_id',     $scheduleres['schedule_id']);
		$stmt->bindValue(':option01',    $scheduleres['option01']);
		$stmt->bindValue(':option02',    $scheduleres['option02']);
		$stmt->bindValue(':option03',    $scheduleres['option03']);
		$stmt->bindValue(':option04',    $scheduleres['option04']);
		$stmt->bindValue(':option05',    $scheduleres['option05']);
		$stmt->bindValue(':option06',    $scheduleres['option06']);
		$stmt->bindValue(':option07',    $scheduleres['option07']);
		$stmt->bindValue(':option08',    $scheduleres['option08']);
		$stmt->bindValue(':option09',    $scheduleres['option09']);
		$stmt->bindValue(':option10',    $scheduleres['option10']);
		$stmt->bindValue(':ip',          $_SERVER['REMOTE_ADDR']);
		$stmt->bindValue(':user_id',     $scheduleres['user_id']);
		$stmt->bindValue(':restriction', $scheduleres['restriction']);
		$flag = $stmt->execute();
		if (!$flag) {
			freo_error($stmt->errorInfo());
		}
		$scheduleres['id']           = $freo->pdo->lastInsertId();
	}

	//入力データ破棄
	$_SESSION['input'] = array();

	//ログ記録
	if (isset($_GET['id'])) {
		freo_log('スケジュールレスポンスを編集しました。');
	} else {
		freo_log('スケジュールレスポンスを新規に登録しました。');
	}

	//スケジュールレスポンス管理へ移動
	if (isset($_GET['id'])) {
		freo_redirect('schedule/view/' . $scheduleres['schedule_id'] . '?exec=scheduleres_update');
	} else {
		freo_redirect('schedule/view/' . $scheduleres['schedule_id'] . '?exec=scheduleres_insert');
	}

	return;
}

/* 管理画面 | スケジュールレスポンス削除 */
function freo_page_scheduleres_admin_delete()
{
	global $freo;

	//ログイン状態確認
	if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
		freo_redirect('login', true);
	}

	//パラメータ検証
	if (!isset($_GET['id']) or !preg_match('/^\d+$/', $_GET['id']) or $_GET['id'] < 1) {
		freo_redirect('scheduleres/admin?error=1');
	}

	//ワンタイムトークン確認
	if (!freo_token('check')) {
		freo_redirect('scheduleres/admin?error=1');
	}

	//スケジュールレスポンス削除
	$stmt = $freo->pdo->prepare('DELETE FROM ' . FREO_DATABASE_PREFIX . 'plugin_schedulereses WHERE id = :id');
	$stmt->bindValue(':id', $_GET['id'], PDO::PARAM_INT);
	$flag = $stmt->execute();
	if (!$flag) {
		freo_error($stmt->errorInfo());
	}

	//連番リセット
	if (FREO_DATABASE_TYPE == 'mysql') {
		$stmt = $freo->pdo->query('ALTER TABLE ' . FREO_DATABASE_PREFIX . 'plugin_schedulereses AUTO_INCREMENT = 0');
		if (!$stmt) {
			freo_error($freo->pdo->errorInfo());
		}
	}

	//ログ記録
	freo_log('スケジュールレスポンスを削除しました。');

	//スケジュールレスポンス管理へ移動
	freo_redirect('scheduleres/admin?exec=delete&id=' . $_GET['id']);

	return;
}

/* スケジュールレスポンス一覧 */
function freo_page_scheduleres_default()
{
	global $freo;

	//パラメータ検証
	if (!isset($_GET['page']) or !preg_match('/^\d+$/', $_GET['page']) or $_GET['page'] < 1) {
		$_GET['page'] = 1;
	}

	//検索条件設定
	$condition = null;
	if (isset($_GET['word'])) {
		$condition .= ' AND text LIKE ' . $freo->pdo->quote('%' . $_GET['word'] . '%') . ' OR name LIKE ' . $freo->pdo->quote('%' . $_GET['word'] . '%');
	}
	if (isset($_GET['date'])) {
		if (preg_match('/^\d\d\d\d$/', $_GET['date'])) {
			if (FREO_DATABASE_TYPE == 'mysql') {
				$condition .= ' AND DATE_FORMAT(created, \'%Y\') = ' . $freo->pdo->quote($_GET['date']);
			} else {
				$condition .= ' AND STRFTIME(\'%Y\', created) = ' . $freo->pdo->quote($_GET['date']);
			}
		} elseif (preg_match('/^\d\d\d\d\d\d$/', $_GET['date'])) {
			if (FREO_DATABASE_TYPE == 'mysql') {
				$condition .= ' AND DATE_FORMAT(created, \'%Y%m\') = ' . $freo->pdo->quote($_GET['date']);
			} else {
				$condition .= ' AND STRFTIME(\'%Y%m\', created) = ' . $freo->pdo->quote($_GET['date']);
			}
		} elseif (preg_match('/^\d\d\d\d\d\d\d\d$/', $_GET['date'])) {
			if (FREO_DATABASE_TYPE == 'mysql') {
				$condition .= ' AND DATE_FORMAT(created, \'%Y%m%d\') = ' . $freo->pdo->quote($_GET['date']);
			} else {
				$condition .= ' AND STRFTIME(\'%Y%m%d\', created) = ' . $freo->pdo->quote($_GET['date']);
			}
		}
	}
	if ($condition) {
		$condition = ' WHERE id IS NOT NULL ' . $condition;
	}

	//スケジュールレスポンス取得
	$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'plugin_schedulereses ' . $condition . ' ORDER BY id DESC LIMIT :start, :limit');
	$stmt->bindValue(':start', intval($freo->config['plugin']['scheduleres']['admin_limit']) * ($_GET['page'] - 1), PDO::PARAM_INT);
	$stmt->bindValue(':limit', intval($freo->config['plugin']['scheduleres']['admin_limit']), PDO::PARAM_INT);
	$flag = $stmt->execute();
	if (!$flag) {
		freo_error($stmt->errorInfo());
	}

	$plugin_schedulereses = array();
	while ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$plugin_schedulereses[$data['id']] = $data;
	}

	//スケジュールレスポンスID取得
	$plugin_scheduleres_keys = array_keys($plugin_schedulereses);

	//スケジュールレスポンス保護データ取得
	$plugin_scheduleres_securities = freo_security_plugin_scheduleres('user', $plugin_scheduleres_keys);

	foreach ($plugin_scheduleres_securities as $id => $security) {
		if (!$security) {
			continue;
		}

		$plugin_schedulereses[$id]['mail']    = NULL;
		$plugin_schedulereses[$id]['url']     = NULL;
		$plugin_schedulereses[$id]['name']    = str_replace('[$name]', $plugin_schedulereses[$id]['name'], $freo->config['plugin']['scheduleres']['restriction_name']);
		$plugin_schedulereses[$id]['text']    = str_replace('[$text]', $plugin_schedulereses[$id]['text'], $freo->config['plugin']['scheduleres']['restriction_text']);

	}

	//スケジュールレスポンス数・ページ数取得
	$stmt = $freo->pdo->query('SELECT COUNT(*) FROM ' . FREO_DATABASE_PREFIX . 'plugin_schedulereses ' . $condition);
	if (!$stmt) {
		freo_error($freo->pdo->errorInfo());
	}

	$data                  = $stmt->fetch(PDO::FETCH_NUM);
	$plugin_scheduleres_count = $data[0];
	$plugin_scheduleres_page  = ceil($plugin_scheduleres_count / $freo->config['plugin']['scheduleres']['admin_limit']);


	//データ割当
	$freo->smarty->assign(array(
		'token'                 => freo_token('create'),
		'plugin_schedulereses'      => $plugin_schedulereses,
		'plugin_scheduleres_count' => $plugin_scheduleres_count,
		'plugin_scheduleres_page'  => $plugin_scheduleres_page,
	));

	return;
}

?>
